@@ -114,7 +114,8 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
 
 
 def preprocessing_training(df, industry_dictionary, state_dictionary,
-                           mx_bv_dictionary, mx_prob_dictionary, config, model_type):
+                           mx_bv_dictionary, mx_prob_dictionary, config, model_type,
+                           use_one_hot_encoding):
     """[Pre-processing function to prepare the data for training the model and to make predictions]
 
     Args:
@@ -145,7 +146,8 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
                                                     model_type=model_type )
 
     df_leads_clean = utils.reduce_mem_usage_category( df=df_leads_clean )
-    df_leads_clean = utils.one_hot_encoding( df=df_leads_clean )
+    if(use_one_hot_encoding):
+        df_leads_clean = utils.one_hot_encoding( df=df_leads_clean )
 
     # Prepare target column
     df_leads_clean = devutils.set_target_column(df=df_leads_clean,model_type=model_type,bins=config['bins'])
@@ -155,3 +157,5 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
     logging.info( f"{nna}" )
 
     return df_leads_clean
+
+
